@@ -12,16 +12,16 @@ class ApplicationManager(TdxManager):
 
     def get(self, app_id: int) -> Application:
         """Gets an Application."""
-        for app in self.get_all():
+        for app in self.all():
             if app.id == app_id:
                 return app
 
     @tdx_method("GET", "/api/applications")
-    def get_all(self) -> List[Application]:
+    def all(self) -> List[Application]:
         """Gets all the applications for an organization."""
         return self.dispatcher.send(
-            self.get_all.method,
-            self.get_all.url,
+            self.all.method,
+            self.all.url,
             rclass=Application,
             rlist=True,
             rpartial=True,
