@@ -32,5 +32,6 @@ class AttachmentManager(TdxManager):
     def delete(self, attachment_id: str) -> None:
         """Deletes an attachment."""
         self.dispatcher.send(
-            self.delete.method, self.delete.url.format(id=attachment_id),
+            self.delete.method,
+            self.delete.url.format(id=attachment_id),
         )
