@@ -1,4 +1,3 @@
-import webbrowser
 from functools import wraps
 
 import attr
@@ -6,14 +5,9 @@ import attr
 
 @attr.s
 class TdxManager(object):
-    dispatcher = attr.ib(repr=False, cmp=False)
+    dispatcher = attr.ib(repr=False, eq=False)
     __tdx_section__ = None
 
-    def docs(self):
-        webbrowser.open_new_tab(
-            f"https://app.teamdynamix.com/TDWebApi/Home/section/{self.__tdx_section__}"
-        )
-
 
 def tdx_method(method, url):
     def wrapper(f):
